==> coreboot-4.4.tar.xz: coreboot-4.4/src/vendorcode/amd/agesa/f15tn/Proc/GNB/Modules/GnbInitTN/GnbCacWeightsTN.h <==
/* $NoKeywords:$ */
/**
 * @file
 *
 * GNB CAC weights table
 *
 *
 *
 * @xrefitem bom "File Content Label" "Release Content"
 * @e project:     AGESA
 * @e sub-project: GNB
 * @e \$Revision: 63425 $   @e \$Date: 2011-12-22 11:24:10 -0600 (Thu, 22 Dec 2011) $
 *
 */
/*
*****************************************************************************
*
 * Copyright (c) 2008 - 2012, Advanced Micro Devices, Inc.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *     * Redistributions of source code must retain the above copyright
 *       notice, this list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above copyright
 *       notice, this list of conditions and the following disclaimer in the
 *       documentation and/or other materials provided with the distribution.
 *     * Neither the name of Advanced Micro Devices, Inc. nor the names of
 *       its contributors may be used to endorse or promote products derived
 *       from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL ADVANCED MICRO DEVICES, INC. BE LIABLE FOR ANY
 * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
* ***************************************************************************
*
*/
#ifndef _GNBCACWEIGHTSTABLETN_H_
#define _GNBCACWEIGHTSTABLETN_H_

UINT32 CacWeightsTN[] = {
  0xD65,
  0x289A,
  0x289A,
  0x0,
  0x0,
  0x0,
  0x0,
  0x0,
  0x0,
  0x0,
  0x16F,
  0x0,
  0x0,
  0x0,
  0x0,
  0x16A5,
  0x592,
  0x0,
  0x0,
  0xE60,
  0x0,
  0xE60,
  0x0,
  0xE60,
  0x0,
  0xE60,
  0x0,
  0xE60,
  0x0,
  0xE60,
  0xEC9,
  0xEC9,
  0x41A,
  0x41A,
  0x0,
  0x0,
  0x0,
  0x0,
  0x0,
  0xF15,
  0xF15,
  0xF15,
  0xF15,
  0xF15,
  0xF15,
  0x79,
  0x79,
  0x79,
  0x0,
  0x0,
  0x0,
  0x0,
  0x3F2,
  0x3F2,
  0x0,
  0x0,
  0x123,
  0x0,
  0x0,
  0x0,
  0x123,
  0x0,
  0x0,
  0x0,
  0x0,
  0x195B,
  0x629,
  0x0,
  0x0,
  0x195B,
  0x629,
  0x0,
  0x0,
  0x0,
  0x0,
  0x0,
  0x0,
  0x0,
  0x755,
  0x0,
  0x755,
  0x0,
  0x755,
  0x0,
  0x755,
  0x0,
  0x755,
  0x0,
  0x755,
  0x0,
  0x88B,
  0x1206,
  0x0,
  0x88B,
  0x1206,
  0x0,
  0x0
};

#endif

==> coreboot-4.18.tar.xz: coreboot-4.18/src/vendorcode/amd/agesa/f15tn/Proc/GNB/Modules/GnbInitTN/GnbCacWeightsTN.h <==
/* $NoKeywords:$ */
/**
 * @file
 *
 * GNB CAC weights table
 *
 *
 *
 * @xrefitem bom "File Content Label" "Release Content"
 * @e project:     AGESA
 * @e sub-project: GNB
 * @e \$Revision: 63425 $   @e \$Date: 2011-12-22 11:24:10 -0600 (Thu, 22 Dec 2011) $
 *
 */
/*
*****************************************************************************
*
 * Copyright (c) 2008 - 2012, Advanced Micro Devices, Inc.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *     * Redistributions of source code must retain the above copyright
 *       notice, this list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above copyright
 *       notice, this list of conditions and the following disclaimer in the
 *       documentation and/or other materials provided with the distribution.
 *     * Neither the name of Advanced Micro Devices, Inc. nor the names of
 *       its contributors may be used to endorse or promote products derived
 *       from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL ADVANCED MICRO DEVICES, INC. BE LIABLE FOR ANY
 * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
* ***************************************************************************
*
*/
#ifndef _GNBCACWEIGHTSTABLETN_H_
#define _GNBCACWEIGHTSTABLETN_H_

CONST UINT32 CacWeightsTN[] = {
  0xD65,
  0x289A,
  0x289A,
  0x0,
  0x0,
  0x0,
  0x0,
  0x0,
  0x0,
  0x0,
  0x16F,
  0x0,
  0x0,
  0x0,
  0x0,
  0x16A5,
  0x592,
  0x0,
  0x0,
  0xE60,
  0x0,
  0xE60,
  0x0,
  0xE60,
  0x0,
  0xE60,
  0x0,
  0xE60,
  0x0,
  0xE60,
  0xEC9,
  0xEC9,
  0x41A,
  0x41A,
  0x0,
  0x0,
  0x0,
  0x0,
  0x0,
  0xF15,
  0xF15,
  0xF15,
  0xF15,
  0xF15,
  0xF15,
  0x79,
  0x79,
  0x79,
  0x0,
  0x0,
  0x0,
  0x0,
  0x3F2,
  0x3F2,
  0x0,
  0x0,
  0x123,
  0x0,
  0x0,
  0x0,
  0x123,
  0x0,
  0x0,
  0x0,
  0x0,
  0x195B,
  0x629,
  0x0,
  0x0,
  0x195B,
  0x629,
  0x0,
  0x0,
  0x0,
  0x0,
  0x0,
  0x0,
  0x0,
  0x755,
  0x0,
  0x755,
  0x0,
  0x755,
  0x0,
  0x755,
  0x0,
  0x755,
  0x0,
  0x755,
  0x0,
  0x88B,
  0x1206,
  0x0,
  0x88B,
  0x1206,
  0x0,
  0x0
};

#endif
